==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/ArrayCore/src/HRFKRadial.cpp <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2017-11-17
**  Copyright: 2017-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "HRFKRadial.h"
#include "FKCrossSpectrum.h"
#include "FKPower.h"

namespace ArrayCore {

  /*!
    \class HRFKRadial HRFKRadial.h
    \brief Radial high resolution FK power

    Radial high resolution FK power versus wavenumber (k) function.
    The cross-spectrum is already projected on the radial direction.
  */

  bool HRFKRadial::invertCrossSpectrum()
  {
    return _crossSpectrum->invertRotatedRayleigh();
  }

  double HRFKRadial::value(const Point& k, int index) const
  {
    if(isInsideLimits(k)) {
      FKPower p(&FKSteeringOneComponent::cache(_gridCache, index));
      p.setCaponValue(_crossSpectrum->rotatedRayleigh(k));
      return p.value();
    } else {
      return -1.0;
    }
  }

  double HRFKRadial::value(const Point& k) const
  {
    if(isInsideLimits(k)) {
      FKSteeringOneComponent * s=static_cast<FKSteeringOneComponent *>(_steering);
      s->initValue(k);
      FKPower p(s);
      p.setCaponValue(_crossSpectrum->rotatedRayleigh(k));
      return p.value();
    } else {
      return -1.0;
    }
  }

} // namespace ArrayCore

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/ArrayCore/src/HRFKRadial.cpp <==
/***************************************************************************
**
**  This file is part of ArrayCore.
**
**  ArrayCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  ArrayCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2017-11-17
**  Copyright: 2017-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#include "HRFKRadial.h"
#include "FKCrossSpectrum.h"
#include "FKPower.h"

namespace ArrayCore {

  /*!
    \class HRFKRadial HRFKRadial.h
    \brief Radial high resolution FK power

    Radial high resolution FK power versus wavenumber (k) function.
    The cross-spectrum is already projected on the radial direction.
  */

  bool HRFKRadial::invertCrossSpectrum()
  {
    return _crossSpectrum->invertRotatedMatrices();
  }

  double HRFKRadial::value(const Point& k, int index) const
  {
    if(isInsideLimits(k)) {
      FKPower p(&FKSteeringOneComponent::cache(_gridCache, index));
      p.setCaponValue(_crossSpectrum->rotatedMatrix(k));
      return p.value();
    } else {
      return -1.0;
    }
  }

  double HRFKRadial::value(const Point& k) const
  {
    if(isInsideLimits(k)) {
      FKSteeringOneComponent * s=static_cast<FKSteeringOneComponent *>(_steering);
      s->initValue(k);
      FKPower p(s);
      p.setCaponValue(_crossSpectrum->rotatedMatrix(k));
      return p.value();
    } else {
      return -1.0;
    }
  }

} // namespace ArrayCore
